==> aws-cdk.aws-cloudformation-1.139.0.tar.gz: aws-cdk.aws-cloudformation-1.139.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-cloudformation",
    "version": "1.139.0",
    "description": "The CDK Construct Library for AWS::CloudFormation",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_cloudformation",
        "aws_cdk.aws_cloudformation._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_cloudformation._jsii": [
            "aws-cloudformation@1.139.0.jsii.tgz"
        ],
        "aws_cdk.aws_cloudformation": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.aws-iam==1.139.0",
        "aws-cdk.aws-lambda==1.139.0",
        "aws-cdk.aws-s3==1.139.0",
        "aws-cdk.aws-sns==1.139.0",
        "aws-cdk.core==1.139.0",
        "aws-cdk.cx-api==1.139.0",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.50.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "Development Status :: 7 - Inactive",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-cloudformation-1.181.0.tar.gz: aws-cdk.aws-cloudformation-1.181.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-cloudformation",
    "version": "1.181.0",
    "description": "The CDK Construct Library for AWS::CloudFormation",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_cloudformation",
        "aws_cdk.aws_cloudformation._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_cloudformation._jsii": [
            "aws-cloudformation@1.181.0.jsii.tgz"
        ],
        "aws_cdk.aws_cloudformation": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk.aws-iam==1.181.0",
        "aws-cdk.aws-lambda==1.181.0",
        "aws-cdk.aws-s3==1.181.0",
        "aws-cdk.aws-sns==1.181.0",
        "aws-cdk.core==1.181.0",
        "aws-cdk.cx-api==1.181.0",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.71.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 7 - Inactive",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
